@@ -138,7 +138,7 @@ def render_file(name, env, output_filename=None, no_output=False,
 
 def render_config(devicename, inventory, env, output_filename,
                   no_output=False, no_squash_blanklines=False,
-                  dump_device=False, debug=False):
+                  dump_device=False, debug=False, **vars):
 
     """Render the configuration for the specified device and write it
     to either standard output or a file, depending on the command line
@@ -538,7 +538,7 @@ if list_env:
 
 if template_filename:
     render_file(template_filename, env, output_filename, no_output,
-                no_squash_blanklines, debug)
+                no_squash_blanklines, debug, inventory=inventory)
 
     exit(0)
 
@@ -564,7 +564,7 @@ for devicename in devicenames:
         complete_success &= render_config(devicename, inventory, env,
                                           output_filename, no_output,
                                           no_squash_blanklines, dump_device,
-                                          debug)
+                                          debug, vars)
 
     except helpers.HelperBaseException as e:
         # one of the explicit helper exceptions has occurred
